Rename macros and types to namespace their usage

Macros and types have been renamed accordingly to namespace them by
their usage in the new kernel driver source tree structure.

This is done in a separate commit from the restructuring to avoid Git
from seeing some of the moved files as new ones because they have been
both moved and modified at the same time and thus losing the connection
in the history.

Change-Id: Icd4d8e8c76779479b5b46a55bf1d4f78a629c281
Signed-off-by: Mikael Olsson <mikael.olsson@arm.com>
diff --git a/kernel/include/rpmsg/ethosu_rpmsg_network_info.h b/kernel/include/rpmsg/ethosu_rpmsg_network_info.h
index aaa3733..a5965c0 100644
--- a/kernel/include/rpmsg/ethosu_rpmsg_network_info.h
+++ b/kernel/include/rpmsg/ethosu_rpmsg_network_info.h
@@ -17,8 +17,8 @@
  * http://www.gnu.org/licenses/gpl-2.0.html.
  */
 
-#ifndef ETHOSU_NETWORK_INFO_H
-#define ETHOSU_NETWORK_INFO_H
+#ifndef ETHOSU_RPMSG_NETWORK_INFO_H
+#define ETHOSU_RPMSG_NETWORK_INFO_H
 
 /****************************************************************************
  * Includes
@@ -33,17 +33,17 @@
  * Types
  ****************************************************************************/
 
-struct ethosu_core_msg_network_info_rsp;
-struct ethosu_network;
+struct ethosu_rpmsg_network_info_rsp;
+struct ethosu_rpmsg_network;
 struct ethosu_uapi_network_info;
 
-struct ethosu_network_info {
+struct ethosu_rpmsg_network_info {
 	struct device                   *dev;
-	struct ethosu_network           *net;
+	struct ethosu_rpmsg_network     *net;
 	struct ethosu_uapi_network_info *uapi;
 	struct completion               done;
 	int                             errno;
-	struct ethosu_mailbox_msg       msg;
+	struct ethosu_rpmsg_mailbox_msg msg;
 };
 
 /****************************************************************************
@@ -51,22 +51,22 @@
  ****************************************************************************/
 
 /**
  * ethosu_network_info_request() - Send a network info request
  *
  * This function must be called in the context of a user space process.
  *
  * Return: 0 on success, .
  */
-int ethosu_network_info_request(struct device *dev,
-				struct ethosu_mailbox *mailbox,
-				struct ethosu_network *net,
-				struct ethosu_uapi_network_info *uapi);
+int ethosu_rpmsg_network_info_request(struct device *dev,
+				      struct ethosu_rpmsg_mailbox *mailbox,
+				      struct ethosu_rpmsg_network *net,
+				      struct ethosu_uapi_network_info *uapi);
 
 /**
  * ethosu_network_info_rsp() - Handle network info response.
  */
-void ethosu_network_info_rsp(struct ethosu_mailbox *mailbox,
-			     int msg_id,
-			     struct ethosu_core_msg_network_info_rsp *rsp);
+void ethosu_rpmsg_network_info_rsp(struct ethosu_rpmsg_mailbox *mailbox,
+				   int msg_id,
+				   struct ethosu_rpmsg_network_info_rsp *rsp);
 
-#endif /* ETHOSU_NETWORK_INFO_H */
+#endif /* ETHOSU_RPMSG_NETWORK_INFO_H */
@@ -51,22 +51,22 @@
 
 /**
- * ethosu_network_info_request() - Send a network info request
+ * ethosu_rpmsg_network_info_request() - Send a network info request
  *
  * This function must be called in the context of a user space process.
@@ -51,22 +51,22 @@
 
 /**
- * ethosu_network_info_rsp() - Handle network info response.
+ * ethosu_rpmsg_network_info_rsp() - Handle network info response.
  */